using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using Android.App;
using Android.Content;
using Android.OS;
using Android.Runtime;
using Android.Views;
using Android.Widget;
using Xamarin.Forms;
using System.IO;
using Syncfusion.Pdf;
using Syncfusion.Pdf.Graphics;
using Syncfusion.SfChart.XForms;
using Syncfusion.SfChart.XForms.Droid;
using Java.IO;

[assembly: Dependency(typeof(SimpleSample.Droid.ChartDependencyService))]
namespace SimpleSample.Droid
{
public class ChartDependencyService : IChartDependencyService
{
    public void SaveAsPDF(string filename, Stream chartStream, SfChart chart, PdfDocument document)
    {
        try
        {
            var page = document.Pages.Add();
            var graphics = page.Graphics;

            graphics.DrawImage(PdfImage.FromStream(chartStream), 0, 0, page.GetClientSize().Width,
            page.GetClientSize().Height);

            MemoryStream stream = new MemoryStream();
            document.Save(stream);
            document.Close(true);
            SavePDF(filename, stream, chart);
        }
        finally
        {
            chartStream.Flush();
            chartStream.Close();
            var nativeChart = SfChartRenderer.GetNativeObject(typeof(SfChart), chart);
            if (((Com.Syncfusion.Charts.SfChart)nativeChart).Parent != null)
            {
                (((Com.Syncfusion.Charts.SfChart)nativeChart).Parent as ViewGroup).RemoveAllViews();
            }
            ((Com.Syncfusion.Charts.SfChart)nativeChart).DrawingCacheEnabled = false;

        }

    }
    private void SavePDF(string fileName, MemoryStream stream, SfChart chart)
    {
        var root = Android.OS.Environment.IsExternalStorageEmulated
                ? Android.OS.Environment.ExternalStorageDirectory.ToString()
                : System.Environment.GetFolderPath(System.Environment.SpecialFolder.MyDocuments);

        var myDir = new Java.IO.File(root + "/Chart");
        myDir.Mkdir();

        var file = new Java.IO.File(myDir, fileName);

        if (file.Exists()) file.Delete();

        try
        {
            var outs = new FileOutputStream(file);
            outs.Write(stream.ToArray());

            outs.Flush();
            outs.Close();

            var nativeChart = SfChartRenderer.GetNativeObject(typeof(SfChart), chart);
          
            ((Com.Syncfusion.Charts.SfChart)nativeChart).DrawingCacheEnabled = false;
        }
        catch (Exception)
        {

        }
        if (!file.Exists()) return;
        var path = Android.Net.Uri.FromFile(file);
        var extension = Android.Webkit.MimeTypeMap.GetFileExtensionFromUrl(Android.Net.Uri.FromFile(file).ToString());
        var mimeType = Android.Webkit.MimeTypeMap.Singleton.GetMimeTypeFromExtension(extension);
        var intent = new Intent(Intent.ActionView);
        intent.SetDataAndType(path, mimeType);
        Forms.Context.StartActivity(Intent.CreateChooser(intent, "Choose App"));
    }
}
}